import { c } from 'react-compiler-runtime';
import React from 'react';
import { defaultSxProp } from '../../utils/defaultSxProp.js';
import { includesSystemProps } from '../../utils/includeSystemProps.js';
import { jsx } from 'react/jsx-runtime';
import Box from '../../Box/Box.js';

/**
 * Utility to toggle rendering a Box component that receives sx props
 * or a "plain" component based on the provided `as` prop. Other props will be passed through to an element or component created with the `as` prop.
 *
 * @param sx - the sx prop to check against the default sx prop
 * @param defaultAs - the default component to use when `as` is not provided
 */
function toggleSxComponent(
// eslint-disable-next-line @typescript-eslint/no-explicit-any
defaultAs) {
  const Wrapper = /*#__PURE__*/React.forwardRef(function Wrapper(t0, ref) {
    const $ = c(13);
    let rest;
    let t1;
    let t2;
    if ($[0] !== t0) {
      ({
        as: t1,
        sx: t2,
        ...rest
      } = t0);
      $[0] = t0;
      $[1] = rest;
      $[2] = t1;
      $[3] = t2;
    } else {
      rest = $[1];
      t1 = $[2];
      t2 = $[3];
    }
    const BaseComponent = t1 === undefined ? defaultAs : t1;
    const sxProp = t2 === undefined ? defaultSxProp : t2;
    if (sxProp !== defaultSxProp || includesSystemProps(rest)) {
      let t3;
      if ($[4] !== BaseComponent || $[5] !== ref || $[6] !== rest || $[7] !== sxProp) {
        t3 = /*#__PURE__*/jsx(Box, {
          as: BaseComponent,
          ...rest,
          sx: sxProp,
          ref: ref
        });
        $[4] = BaseComponent;
        $[5] = ref;
        $[6] = rest;
        $[7] = sxProp;
        $[8] = t3;
      } else {
        t3 = $[8];
      }
      return t3;
    }
    let t3;
    if ($[9] !== BaseComponent || $[10] !== ref || $[11] !== rest) {
      t3 = /*#__PURE__*/jsx(BaseComponent, {
        ...rest,
        ref: ref
      });
      $[9] = BaseComponent;
      $[10] = ref;
      $[11] = rest;
      $[12] = t3;
    } else {
      t3 = $[12];
    }
    return t3;
  });
  return Wrapper;
}

export { toggleSxComponent };
